@@ -187,6 +187,7 @@ class Runtime(RestAdapterBase):
         self,
         limit: int = None,
         skip: int = None,
+        backend_name: str = None,
         pending: bool = None,
         program_id: str = None,
         hub: str = None,
@@ -203,6 +204,7 @@ class Runtime(RestAdapterBase):
         Args:
             limit: Number of results to return.
             skip: Number of results to skip.
+            backend_name: Name of the backend to retrieve jobs from.
             pending: Returns 'QUEUED' and 'RUNNING' jobs if True,
                 returns 'DONE', 'CANCELLED' and 'ERROR' jobs if False.
             program_id: Filter by Program ID.
@@ -229,6 +231,8 @@ class Runtime(RestAdapterBase):
             payload["limit"] = limit
         if skip:
             payload["offset"] = skip
+        if backend_name:
+            payload["backend"] = backend_name
         if pending is not None:
             payload["pending"] = "true" if pending else "false"
         if program_id:
