@@ -28,7 +28,7 @@ FILE_HEADER = namedtuple(
         "major_version",
         "minor_version",
         "patch_version",
-        "num_circuits",
+        "num_programs",
     ],
 )
 FILE_HEADER_PACK = "!6sBBBBQ"
@@ -95,6 +95,26 @@ CIRCUIT_INSTRUCTION = namedtuple(
 CIRCUIT_INSTRUCTION_PACK = "!HHHII?Hq"
 CIRCUIT_INSTRUCTION_SIZE = struct.calcsize(CIRCUIT_INSTRUCTION_PACK)
 
+# CIRCUIT_INSTRUCTION_V2
+CIRCUIT_INSTRUCTION_V2 = namedtuple(
+    "CIRCUIT_INSTRUCTION",
+    [
+        "name_size",
+        "label_size",
+        "num_parameters",
+        "num_qargs",
+        "num_cargs",
+        "has_condition",
+        "condition_register_size",
+        "condition_value",
+        "num_ctrl_qubits",
+        "ctrl_state",
+    ],
+)
+CIRCUIT_INSTRUCTION_V2_PACK = "!HHHII?HqII"
+CIRCUIT_INSTRUCTION_V2_SIZE = struct.calcsize(CIRCUIT_INSTRUCTION_V2_PACK)
+
+
 # CIRCUIT_INSTRUCTION_ARG
 CIRCUIT_INSTRUCTION_ARG = namedtuple("CIRCUIT_INSTRUCTION_ARG", ["type", "size"])
 CIRCUIT_INSTRUCTION_ARG_PACK = "!1cI"
@@ -118,6 +138,24 @@ CUSTOM_CIRCUIT_DEF_HEADER = namedtuple("CUSTOM_CIRCUIT_DEF_HEADER", ["size"])
 CUSTOM_CIRCUIT_DEF_HEADER_PACK = "!Q"
 CUSTOM_CIRCUIT_DEF_HEADER_SIZE = struct.calcsize(CUSTOM_CIRCUIT_DEF_HEADER_PACK)
 
+# CUSTOM_CIRCUIT_INST_DEF_V2
+CUSTOM_CIRCUIT_INST_DEF_V2 = namedtuple(
+    "CUSTOM_CIRCUIT_INST_DEF",
+    [
+        "gate_name_size",
+        "type",
+        "num_qubits",
+        "num_clbits",
+        "custom_definition",
+        "size",
+        "num_ctrl_qubits",
+        "ctrl_state",
+        "base_gate_size",
+    ],
+)
+CUSTOM_CIRCUIT_INST_DEF_V2_PACK = "!H1cII?QIIQ"
+CUSTOM_CIRCUIT_INST_DEF_V2_SIZE = struct.calcsize(CUSTOM_CIRCUIT_INST_DEF_V2_PACK)
+
 # CUSTOM_CIRCUIT_INST_DEF
 CUSTOM_CIRCUIT_INST_DEF = namedtuple(
     "CUSTOM_CIRCUIT_INST_DEF",
@@ -126,8 +164,66 @@ CUSTOM_CIRCUIT_INST_DEF = namedtuple(
 CUSTOM_CIRCUIT_INST_DEF_PACK = "!H1cII?Q"
 CUSTOM_CIRCUIT_INST_DEF_SIZE = struct.calcsize(CUSTOM_CIRCUIT_INST_DEF_PACK)
 
+# CALIBRATION
+CALIBRATION = namedtuple("CALIBRATION", ["num_cals"])
+CALIBRATION_PACK = "!H"
+CALIBRATION_SIZE = struct.calcsize(CALIBRATION_PACK)
+
+# CALIBRATION_DEF
+CALIBRATION_DEF = namedtuple(
+    "CALIBRATION_DEF", ["name_size", "num_qubits", "num_params", "type"]
+)
+CALIBRATION_DEF_PACK = "!HHH1c"
+CALIBRATION_DEF_SIZE = struct.calcsize(CALIBRATION_DEF_PACK)
+
+# SCHEDULE_BLOCK binary format
+SCHEDULE_BLOCK_HEADER = namedtuple(
+    "SCHEDULE_BLOCK",
+    [
+        "name_size",
+        "metadata_size",
+        "num_elements",
+    ],
+)
+SCHEDULE_BLOCK_HEADER_PACK = "!HQH"
+SCHEDULE_BLOCK_HEADER_SIZE = struct.calcsize(SCHEDULE_BLOCK_HEADER_PACK)
+
+# WAVEFORM binary format
+WAVEFORM = namedtuple("WAVEFORM", ["epsilon", "data_size", "amp_limited"])
+WAVEFORM_PACK = "!fI?"
+WAVEFORM_SIZE = struct.calcsize(WAVEFORM_PACK)
+
+# SYMBOLIC_PULSE
+SYMBOLIC_PULSE = namedtuple(
+    "SYMBOLIC_PULSE",
+    [
+        "type_size",
+        "envelope_size",
+        "constraints_size",
+        "valid_amp_conditions_size",
+        "amp_limited",
+    ],
+)
+SYMBOLIC_PULSE_PACK = "!HHHH?"
+SYMBOLIC_PULSE_SIZE = struct.calcsize(SYMBOLIC_PULSE_PACK)
+
+# SYMBOLIC_PULSE_V2
+SYMBOLIC_PULSE_V2 = namedtuple(
+    "SYMBOLIC_PULSE",
+    [
+        "class_name_size",
+        "type_size",
+        "envelope_size",
+        "constraints_size",
+        "valid_amp_conditions_size",
+        "amp_limited",
+    ],
+)
+SYMBOLIC_PULSE_PACK_V2 = "!HHHHH?"
+SYMBOLIC_PULSE_SIZE_V2 = struct.calcsize(SYMBOLIC_PULSE_PACK_V2)
+
 # INSTRUCTION_PARAM
-INSTRUCTION_PARAM = namedtuple("TYPED_OBJECT", ["type", "size"])
+INSTRUCTION_PARAM = namedtuple("INSTRUCTION_PARAM", ["type", "size"])
 INSTRUCTION_PARAM_PACK = "!1cQ"
 INSTRUCTION_PARAM_SIZE = struct.calcsize(INSTRUCTION_PARAM_PACK)
 
@@ -174,3 +270,8 @@ RANGE_SIZE = struct.calcsize(RANGE_PACK)
 SEQUENCE = namedtuple("SEQUENCE", ["num_elements"])
 SEQUENCE_PACK = "!Q"
 SEQUENCE_SIZE = struct.calcsize(SEQUENCE_PACK)
+
+# MAP_ITEM
+MAP_ITEM = namedtuple("MAP_ITEM", ["key_size", "type", "size"])
+MAP_ITEM_PACK = "!H1cH"
+MAP_ITEM_SIZE = struct.calcsize(MAP_ITEM_PACK)
