@@ -99,7 +99,7 @@ class no_file(ContextDecorator):
 
 
 class temporary_account_config_file(ContextDecorator):
-    """Context manager that uses a temporary qiskitrc."""
+    """Context manager that uses a temporary json file."""
 
     # pylint: disable=invalid-name
 
@@ -125,6 +125,29 @@ class temporary_account_config_file(ContextDecorator):
         management._DEFAULT_ACCOUNT_CONFIG_JSON_FILE = self.account_config_json_backup
 
 
+class custom_qiskitrc(ContextDecorator):
+    """Context manager that uses a temporary qiskitrc."""
+
+    # pylint: disable=invalid-name
+
+    def __init__(self, contents=b""):
+        # Create a temporary file with the contents.
+        self.tmp_file = NamedTemporaryFile()
+        self.tmp_file.write(contents)
+        self.tmp_file.flush()
+        self.default_qiskitrc_file_original = management._QISKITRC_CONFIG_FILE
+
+    def __enter__(self):
+        # Temporarily modify the default location of the qiskitrc file.
+        management._QISKITRC_CONFIG_FILE = self.tmp_file.name
+        return self
+
+    def __exit__(self, *exc):
+        # Delete the temporary file and restore the default location.
+        self.tmp_file.close()
+        management._QISKITRC_CONFIG_FILE = self.default_qiskitrc_file_original
+
+
 def get_account_config_contents(
     name=None,
     channel="ibm_cloud",
