@@ -19,6 +19,7 @@ from qiskit.circuit import QuantumCircuit, Gate
 from qiskit.circuit.library import RealAmplitudes
 from qiskit.test.reference_circuits import ReferenceCircuits
 from qiskit.primitives import BaseSampler, SamplerResult
+from qiskit.result import QuasiDistribution
 
 from qiskit_ibm_runtime import Sampler, Session
 from qiskit_ibm_runtime.exceptions import RuntimeJobFailureError
@@ -51,6 +52,7 @@ class TestIntegrationIBMSampler(IBMIntegrationTestCase):
             self.assertAlmostEqual(result.quasi_dists[0][3], 0.5, delta=0.1)
             self.assertAlmostEqual(result.quasi_dists[0][0], 0.5, delta=0.1)
             self.assertTrue(session.session_id)
+            session.close()
 
     @run_integration_test
     def test_sampler_non_parameterized_circuits(self, service):
@@ -87,6 +89,7 @@ class TestIntegrationIBMSampler(IBMIntegrationTestCase):
             for i in range(len(circuits3)):
                 self.assertAlmostEqual(result3.quasi_dists[i][3], 0.5, delta=0.1)
                 self.assertAlmostEqual(result3.quasi_dists[i][0], 0.5, delta=0.1)
+            session.close()
 
     @unittest.skip("Skip until data caching is reenabled.")
     @run_integration_test
@@ -135,6 +138,7 @@ class TestIntegrationIBMSampler(IBMIntegrationTestCase):
             self.assertEqual(len(result.metadata), 2)
             self.assertEqual(result.quasi_dists[0][3], 1)
             self.assertEqual(result.quasi_dists[1][31], 1)
+            session.close()
 
     @unittest.skip("Skip until data caching is reenabled.")
     @run_integration_test
@@ -165,6 +169,7 @@ class TestIntegrationIBMSampler(IBMIntegrationTestCase):
             job = sampler.run(circuits=[qc1], transpilation=transpilation)
             with self.assertRaises(RuntimeJobFailureError):
                 job.result()
+            session.close()
 
     @run_integration_test
     def test_sampler_primitive_parameterized_circuits(self, service):
@@ -192,6 +197,7 @@ class TestIntegrationIBMSampler(IBMIntegrationTestCase):
             self.assertIsInstance(result, SamplerResult)
             self.assertEqual(len(result.quasi_dists), len(circuits0))
             self.assertEqual(len(result.metadata), len(circuits0))
+            session.close()
 
     @run_integration_test
     def test_sampler_skip_transpile(self, service):
@@ -207,6 +213,7 @@ class TestIntegrationIBMSampler(IBMIntegrationTestCase):
                 sampler.run(circuits=circ, skip_transpilation=True).result()
                 # If transpilation not skipped the error would be something about cannot expand.
                 self.assertIn("invalid instructions", err.exception.message)
+                session.close()
 
     @run_integration_test
     def test_sampler_optimization_level(self, service):
@@ -221,6 +228,7 @@ class TestIntegrationIBMSampler(IBMIntegrationTestCase):
             )
             self.assertAlmostEqual(result.quasi_dists[0][3], 0.5, delta=0.1)
             self.assertAlmostEqual(result.quasi_dists[0][0], 0.5, delta=0.1)
+            session.close()
 
     @run_integration_test
     def test_sampler_primitive_as_session(self, service):
@@ -270,6 +278,11 @@ class TestIntegrationIBMSampler(IBMIntegrationTestCase):
             job = sampler.run(circuits=[self.bell] * 20, callback=_callback)
             result = job.result()
 
-            self.assertEqual(result.quasi_dists, ws_result[-1].quasi_dists)
+            self.assertIsInstance(ws_result[-1], dict)
+            ws_result_quasi = [
+                QuasiDistribution(quasi) for quasi in ws_result[-1]["quasi_dists"]
+            ]
+            self.assertEqual(result.quasi_dists, ws_result_quasi)
             self.assertEqual(len(job_ids), 1)
             self.assertEqual(job.job_id(), job_ids.pop())
+            session.close()
