@@ -86,7 +86,14 @@ def run_program(
 ):
     """Run a program."""
     backend_name = backend_name if backend_name is not None else "common_backend"
-    options = {"backend_name": backend_name, "image": image, "log_level": log_level}
+    options = {
+        "backend": backend_name,
+        "image": image,
+        "log_level": log_level,
+        "job_tags": job_tags,
+        "max_execution_time": max_execution_time,
+        "instance": instance,
+    }
     if final_status is not None:
         service._api_client.set_final_status(final_status)
     elif job_classes:
@@ -98,9 +105,6 @@ def run_program(
         options=options,
         inputs=inputs,
         result_decoder=decoder,
-        instance=instance,
-        job_tags=job_tags,
-        max_execution_time=max_execution_time,
         session_id=session_id,
     )
     job._creation_date = datetime.now(timezone.utc)
