@@ -17,6 +17,7 @@ import logging
 import time
 import unittest
 from unittest import mock
+from typing import Dict
 
 from qiskit.circuit import QuantumCircuit
 from qiskit.providers.jobstatus import JOB_FINAL_STATES, JobStatus
@@ -109,7 +110,7 @@ def cancel_job_safe(job: RuntimeJob, logger: logging.Logger) -> bool:
         assert (
             status is JobStatus.CANCELLED
         ), "cancel() was successful for job {} but its " "status is {}.".format(
-            job.job_id, status
+            job.job_id(), status
         )
         return True
     except RuntimeInvalidStateError:
@@ -126,7 +127,7 @@ def wait_for_status(job, status, poll_time=1, time_out=20):
         time.sleep(wait_time)
         time_out -= wait_time
     if job.status() != status:
-        raise unittest.SkipTest(f"Job {job.job_id} unable to reach status {status}.")
+        raise unittest.SkipTest(f"Job {job.job_id()} unable to reach status {status}.")
 
 
 def get_real_device(service):
@@ -145,5 +146,51 @@ def mock_wait_for_final_state(service, job):
     return mock.patch.object(
         RuntimeJob,
         "wait_for_final_state",
-        side_effect=service._api_client.wait_for_final_state(job.job_id),
+        side_effect=service._api_client.wait_for_final_state(job.job_id()),
     )
+
+
+def dict_paritally_equal(dict1: Dict, dict2: Dict) -> bool:
+    """Determine whether all keys in dict2 are in dict1 and have same values."""
+    for key, val in dict2.items():
+        if isinstance(val, dict):
+            if not dict_paritally_equal(dict1.get(key), val):
+                return False
+        elif key not in dict1 or val != dict1[key]:
+            return False
+
+    return True
+
+
+def flat_dict_partially_equal(dict1: dict, dict2: dict) -> bool:
+    """Flat the dictionaries then determine whether all keys in dict2 are
+    in dict1 and have the same values."""
+
+    def _flat_dict(in_dict, out_dict):
+        for key_, val_ in in_dict.items():
+            if isinstance(val_, dict):
+                _flat_dict(val_, out_dict)
+            else:
+                out_dict[key_] = val_
+
+    flat_dict1: dict = {}
+    flat_dict2: dict = {}
+    _flat_dict(dict1, flat_dict1)
+    _flat_dict(dict2, flat_dict2)
+
+    for key, val in flat_dict2.items():
+        if key not in flat_dict1 or flat_dict1[key] != val:
+            return False
+    return True
+
+
+def dict_keys_equal(dict1: dict, dict2: dict) -> bool:
+    """Determine whether the dictionaries have the same keys."""
+    for key, val in dict1.items():
+        if key not in dict2:
+            return False
+        if isinstance(val, dict):
+            if not dict_keys_equal(val, dict2[key]):
+                return False
+
+    return True
